@@ -20,13 +20,22 @@ int main()
   clock_gettime(CLOCK_REALTIME, &ts);
   clock_settime(CLOCK_REALTIME, &ts);
   clock_getres(CLOCK_REALTIME, &ts);
+  return 0;
+}
+|}
+
+let clock_getcpuclockid_code = {|
+#include <time.h>
+
+int main()
+{
   clock_getcpuclockid(0, CLOCK_REALTIME);
   return 0;
 }
 |}
 
 type posix_timers =
-  | Available of { need_lrt : bool }
+  | Available of { need_lrt : bool; getcpuclockid : bool }
   | Not_available
 
 let timespec_code = {|
@@ -127,6 +136,7 @@ int main () {
 |}
 
 let mkostemp_code = {|
+#define _GNU_SOURCE
 #include <stdlib.h>
 
 int main () {
@@ -170,9 +180,11 @@ let () =
     let posix_timers =
       C.c_test c posix_timers_code
     in
-
+    let clock_getcpuclockid =
+      C.c_test c clock_getcpuclockid_code
+    in
     let thread_id_method =
-      let thread_id_header = Caml.Filename.concat (Caml.Sys.getcwd ()) "thread_id.h" in
+      let thread_id_header = Stdlib.Filename.concat (Stdlib.Sys.getcwd ()) "thread_id.h" in
       List.find [1; 2] ~f:(fun thread_id_method ->
         C.c_test c (thread_id_code ~thread_id_method ~thread_id_header))
       |> Option.value ~default:(-1)
@@ -226,10 +238,12 @@ let () =
         [ rlimit_vars
         ; ocaml_vars
         ; simple_vars
-        ; [ "POSIX_TIMERS"    , Switch posix_timers
-          ; "THREAD_ID_METHOD", Int thread_id_method
-          ; "LINUX_EXT"       , Switch linux
-          ]
+        ; [
+          "POSIX_TIMERS"    , Switch posix_timers
+        ; "CLOCK_GETCPUCLOCKID"    , Switch clock_getcpuclockid
+        ; "THREAD_ID_METHOD", Int thread_id_method
+        ; "LINUX_EXT"       , Switch linux
+        ]
         ]
     in
 
